You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@giraph.apache.org by "ASF GitHub Bot (JIRA)" <ji...@apache.org> on 2018/04/06 21:21:00 UTC

[jira] [Commented] (GIRAPH-1185) Adding faster serialization classes.

    [ https://issues.apache.org/jira/browse/GIRAPH-1185?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16429023#comment-16429023 ] 

ASF GitHub Bot commented on GIRAPH-1185:
----------------------------------------

GitHub user yukselakinci opened a pull request:

    https://github.com/apache/giraph/pull/69

    GIRAPH-1185

    Second PR for serialization. There is one more.

You can merge this pull request into a Git repository by running:

    $ git pull https://github.com/yukselakinci/giraph phase22

Alternatively you can review and apply these changes as the patch at:

    https://github.com/apache/giraph/pull/69.patch

To close this pull request, make a commit to your master/trunk branch
with (at least) the following in the commit message:

    This closes #69
    
----
commit 849d638cb63d0721d6e725b196eb35b156b45985
Author: Yuksel Akinci <yu...@...>
Date:   2018-04-06T05:42:42Z

    GIRAPH-1185

----


> Adding faster serialization classes.
> ------------------------------------
>
>                 Key: GIRAPH-1185
>                 URL: https://issues.apache.org/jira/browse/GIRAPH-1185
>             Project: Giraph
>          Issue Type: Improvement
>            Reporter: Yuksel Akinci
>            Priority: Major
>
> These changes add two new kryo serialization classes (KryoSimpleWritable and KryoSimpleWrapper) which disable reference tracking at the expense of not supporting recursive and nested structures. Disabling reference tracking significantly improves the serialization performance. One a sample pipeline, the running time reduced from 75 minutes to 5 minutes.



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)